@@ -41,6 +41,8 @@ from astropy.cosmology import FlatLambdaCDM
 import astropy.units as u
 cosmo = FlatLambdaCDM(H0=70 * u.km / u.s / u.Mpc, Tcmb0=2.725 * u.K, Om0=0.3)
 
+from typing import Tuple
+
 # -----------------------
 # Methods
 # -----------------------
@@ -278,9 +280,9 @@ def get_patches(RA_list: np.ndarray,
                 DEC_list: np.ndarray,
                 n_patches: int,
                 center_guesses: np.ndarray,
-                survey='kids': str,
-                numba_installed=True: bool,
-                plot_savename='none': str) -> np.ndarray:
+                survey='kids',
+                numba_installed=True,
+                plot_savename='none') -> np.ndarray:
     """
     Divides survey into equally distributed and equally sized patches.
     Returns labels for patches from RA, Dec, Number of patches and patch center guesses.
@@ -417,9 +419,9 @@ def plot_LF(rest_mag_list: np.ndarray,
             DEC_list: np.ndarray,
             n_patches: int,
             center_guesses: np.ndarray,
-            survey='kids': str,
-            numba_installed=True: bool,
-            plot_savename='none': str) -> np.ndarray:
+            survey='kids',
+            numba_installed=True,
+            plot_savename='none') -> np.ndarray:
     """
     Plots the 1/Vmax weighted luminosity function from data, binned by magnitude.
 
@@ -507,9 +509,9 @@ def analyse_LF_by_colour(dichotomy_slope: float,
                          DEC_list: np.ndarray,
                          n_patches: int,
                          center_guesses: np.ndarray,
-                         survey='kids': str,
-                         numba_installed=True: bool,
-                         plot_savename='none': str) -> np.ndarray:
+                         survey='kids',
+                         numba_installed=True,
+                         plot_savename='none') -> np.ndarray:
     """
     Plots the 1/Vmax weighted luminosity function from data, binned by magnitude and filtered by galaxy colours.
 
@@ -766,7 +768,7 @@ def get_schechter_phi(M_list: np.ndarray,
                       phi_list: np.ndarray,
                       phi_err_list: np.ndarray,
                       guesses: np.ndarray,
-                      plot_savename='none': str) -> Tuple[np.ndarray, float, float, float, float, float, float, float]:
+                      plot_savename='none') -> Tuple[np.ndarray, float, float, float, float, float, float, float]:
     """
     Best fits single Schechter model on data. Returns best fit phi and reduced chi squared estimate alongside Schechter parameters and their errors.
 
@@ -880,7 +882,7 @@ def get_double_schechter_phi(M_list: np.ndarray,
                              phi_list: np.ndarray,
                              phi_err_list: np.ndarray,
                              guesses: np.ndarray,
-                             plot_savename='none': str) -> Tuple[np.ndarray, float, float, float, float, float, float, float, float, float, float, float]:
+                             plot_savename='none') -> Tuple[np.ndarray, float, float, float, float, float, float, float, float, float, float, float]:
     """
     Parameters
     ----------
